@@ -19,7 +19,7 @@
  */
 
 #include "base_db_table_data.h"
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
 #include <glom/application.h>
 #include "python_embed/glom_python.h"
 #include <sstream>
@@ -59,8 +59,15 @@ Gnome::Gda::Value Base_DB_Table_Data::get_entered_field_data(const sharedptr<con
   return Gnome::Gda::Value(); //null
 }
 
+Gtk::TreeModel::iterator Base_DB_Table_Data::get_row_selected()
+{
+  //This in meaningless for Details, 
+  //but is overridden for list views.
+  return Gtk::TreeModel::iterator();
+}
 
-Glib::RefPtr<Gnome::Gda::DataModel> Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Value& primary_key_value)
+
+bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Value& primary_key_value)
 {
   sharedptr<const Field> fieldPrimaryKey = get_field_primary_key();
 
@@ -147,7 +154,8 @@ Glib::RefPtr<Gnome::Gda::DataModel> Base_DB_Table_Data::record_new(bool use_ente
   //Avoid specifying the same field twice:
   typedef std::map<Glib::ustring, bool> type_map_added;
   type_map_added map_added;
-
+  Glib::RefPtr<Gnome::Gda::Set> params = Gnome::Gda::Set::create();
+  
   for(type_vecLayoutFields::const_iterator iter = fieldsToAdd.begin(); iter != fieldsToAdd.end(); ++iter)
   {
     sharedptr<LayoutItem_Field> layout_item = *iter;
@@ -159,7 +167,7 @@ Glib::RefPtr<Gnome::Gda::DataModel> Base_DB_Table_Data::record_new(bool use_ente
       {
         Gnome::Gda::Value value;
 
-        const sharedptr<const Field>& field = layout_item->get_full_field_details();
+        const sharedptr<const Field>& field = layout_item->get_full_field_details();        
         if(field)
         {
           //Use the specified (generated) primary key value, if there is one:
@@ -183,9 +191,7 @@ Glib::RefPtr<Gnome::Gda::DataModel> Base_DB_Table_Data::record_new(bool use_ente
             } 
           }
           */
-
-          const Glib::ustring strFieldValue = field->sql(value);
-          if(!strFieldValue.empty())
+          if(!value.is_null())
           {
             if(!strNames.empty())
             {
@@ -194,7 +200,9 @@ Glib::RefPtr<Gnome::Gda::DataModel> Base_DB_Table_Data::record_new(bool use_ente
             }
   
             strNames += "\"" + field_name + "\"";
-            strValues += strFieldValue;
+            strValues += field->get_gda_holder_string();
+            Glib::RefPtr<Gnome::Gda::Holder> holder = field->get_holder(value);
+            params->add_holder(holder);
   
             map_added[field_name] = true;
           }
@@ -204,40 +212,43 @@ Glib::RefPtr<Gnome::Gda::DataModel> Base_DB_Table_Data::record_new(bool use_ente
   }
 
   //Put it all together to create the record with these field values:
-  Glib::RefPtr<Gnome::Gda::DataModel> result;
   if(!strNames.empty() && !strValues.empty())
   {
     const Glib::ustring strQuery = "INSERT INTO \"" + m_table_name + "\" (" + strNames + ") VALUES (" + strValues + ")";
-    result = query_execute(strQuery, App_Glom::get_application());
-    if(result)
+    const bool test = query_execute(strQuery, params);
+    if(!test)
+      std::cerr << "Box_Data::record_new(): INSERT failed." << std::endl;
+    else
     {
-      Gtk::TreeModel::iterator row; // TODO: remove this parameter.
+      Gtk::TreeModel::iterator row = get_row_selected(); //Null and ignored for details views.
       set_primary_key_value(row, primary_key_value); //Needed by Box_Data_List::on_adddel_user_changed().
 
       //Update any lookups, related fields, or calculations:
       for(type_vecLayoutFields::const_iterator iter = fieldsToAdd.begin(); iter != fieldsToAdd.end(); ++iter)
       {
-         sharedptr<const LayoutItem_Field> layout_item = *iter;
+        sharedptr<const LayoutItem_Field> layout_item = *iter;
          
-         //TODO_Performance: We just set this with set_entered_field_data() above. Maybe we could just remember it.
-         const Gnome::Gda::Value field_value = get_entered_field_data(layout_item);
+        //TODO_Performance: We just set this with set_entered_field_data() above. Maybe we could just remember it.
+        const Gnome::Gda::Value field_value = get_entered_field_data(layout_item);
 
-         LayoutFieldInRecord field_in_record(layout_item, m_table_name, fieldPrimaryKey, primary_key_value);
+        LayoutFieldInRecord field_in_record(layout_item, m_table_name, fieldPrimaryKey, primary_key_value);
 
-         //Get-and-set values for lookup fields, if this field triggers those relationships:
-         do_lookups(field_in_record, row, field_value);
+        //Get-and-set values for lookup fields, if this field triggers those relationships:
+        do_lookups(field_in_record, row, field_value);
 
-         //Update related fields, if this field is used in the relationship:
-         refresh_related_fields(field_in_record, row, field_value);
+        //Update related fields, if this field is used in the relationship:
+        refresh_related_fields(field_in_record, row, field_value);
+
+        //TODO: Put the inserted row into result, somehow? murrayc
+
+        return true; //success
       }
     }
-    else
-    {
-      std::cerr << "Box_Data::record_new(): INSERT returned null DataModel." << std::endl; 
-    }
   }
+  else
+    std::cerr << "Base_DB_Table_Data::record_new(): Empty field names or values." << std::endl;
 
-  return result; //Failed.
+  return false; //Failed.
 }
 
 
@@ -258,7 +269,7 @@ bool Base_DB_Table_Data::get_related_record_exists(const sharedptr<const Relatio
 
   //TODO_Performance: Is this the best way to just find out whether there is one record that meets this criteria?
   const Glib::ustring query = "SELECT \"" + to_field + "\" FROM \"" + relationship->get_to_table() + "\" WHERE \"" + related_table + "\".\"" + to_field + "\" = " + key_field->sql(key_value);
-  Glib::RefPtr<Gnome::Gda::DataModel> records = query_execute(query, App_Glom::get_application());
+  Glib::RefPtr<Gnome::Gda::DataModel> records = query_execute_select(query);
   if(!records)
     handle_error();
   else
@@ -345,11 +356,15 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
 
         //Generate the new key value;
       }
-
-      const Glib::ustring strQuery = "INSERT INTO \"" + relationship->get_to_table() + "\" (\"" + primary_key_field->get_name() + "\") VALUES (" + primary_key_field->sql(primary_key_value) + ")";
-      const bool test = query_execute(strQuery, App_Glom::get_application());
+      Glib::RefPtr<Gnome::Gda::Set> params = Gnome::Gda::Set::create();
+      params->add_holder(primary_key_field->get_holder(primary_key_value));
+      const Glib::ustring strQuery = "INSERT INTO \"" + relationship->get_to_table() + "\" (\"" + primary_key_field->get_name() + "\") VALUES (" + primary_key_field->get_gda_holder_string() + ")";
+      const bool test = query_execute(strQuery, params);
       if(!test)
+      {
+        std::cerr << "Base_DB_Table_Data::add_related_record_for_field(): INSERT failed." << std::endl;
         return false;
+      }
 
       if(key_is_auto_increment)
       {
@@ -384,11 +399,15 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
           }
           else
           {
-            const Glib::ustring strQuery = "UPDATE \"" + relationship->get_from_table() + "\" SET \"" + relationship->get_from_field() + "\" = " + primary_key_field->sql(primary_key_value) +
-              " WHERE \"" + relationship->get_from_table() + "\".\"" + parent_primary_key_field->get_name() + "\" = " + parent_primary_key_field->sql(parent_primary_key_value);
-            const bool test = query_execute(strQuery, App_Glom::get_application());
+            params->add_holder(parent_primary_key_field->get_holder(parent_primary_key_value));
+            const Glib::ustring strQuery = "UPDATE \"" + relationship->get_from_table() + "\" SET \"" + relationship->get_from_field() + "\" = " + primary_key_field->get_gda_holder_string() +
+              " WHERE \"" + relationship->get_from_table() + "\".\"" + parent_primary_key_field->get_name() + "\" = " +  parent_primary_key_field->get_gda_holder_string();
+            const bool test = query_execute(strQuery, params);
             if(!test)
+            {
+              std::cerr << "Base_DB_Table_Data::add_related_record_for_field(): UPDATE failed." << std::endl;
               return false;
+            }
           }
         }
       }
@@ -436,7 +455,9 @@ bool Base_DB_Table_Data::record_delete(const Gnome::Gda::Value& primary_key_valu
   sharedptr<Field> field_primary_key = get_field_primary_key();
   if(field_primary_key && !Conversions::value_is_empty(primary_key_value))
   {
-    return query_execute( "DELETE FROM \"" + m_table_name + "\" WHERE \"" + m_table_name + "\".\"" + field_primary_key->get_name() + "\" = " + field_primary_key->sql(primary_key_value), App_Glom::get_application());
+    Glib::RefPtr<Gnome::Gda::Set> params = Gnome::Gda::Set::create();
+    params->add_holder(field_primary_key->get_holder(primary_key_value));
+    return query_execute( "DELETE FROM \"" + m_table_name + "\" WHERE \"" + m_table_name + "\".\"" + field_primary_key->get_name() + "\" = " + field_primary_key->get_gda_holder_string(), params);
   }
   else
   {
@@ -449,6 +470,102 @@ Base_DB_Table_Data::type_signal_record_changed Base_DB_Table_Data::signal_record
   return m_signal_record_changed;
 }
 
+
+void Base_DB_Table_Data::refresh_related_fields(const LayoutFieldInRecord& field_in_record_changed, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& /* field_value */)
+{
+  //std::cout << "DEBUG: Base_DB_Table_Data::refresh_related_fields()" << std::endl;
+
+  if(field_in_record_changed.m_table_name != m_table_name)
+    return; //TODO: Handle these too?
+
+  //Get values for lookup fields, if this field triggers those relationships:
+  //TODO_performance: There is a LOT of iterating and copying here.
+  //const Glib::ustring strFieldName = field_in_record_changed.m_field->get_name();
+  type_vecLayoutFields fieldsToGet = get_related_fields(field_in_record_changed.m_field);
+
+  if(!fieldsToGet.empty())
+  {
+    const Glib::ustring query = Utils::build_sql_select_with_key(field_in_record_changed.m_table_name, fieldsToGet, field_in_record_changed.m_key, field_in_record_changed.m_key_value);
+    //std::cout << "DEBUG: Base_DB_Table_Data::refresh_related_fields(): query=" << query << std::endl;
+
+    Glib::RefPtr<Gnome::Gda::DataModel> result = query_execute_select(query);
+    if(!result)
+    {
+      std::cerr << "Base_DB_Table_Data::refresh_related_fields(): no result." << std::endl;
+      handle_error();
+    }
+    else
+    {
+      //Field contents:
+      if(result->get_n_rows())
+      {
+        type_vecLayoutFields::const_iterator iterFields = fieldsToGet.begin();
+
+        const guint cols_count = result->get_n_columns();
+        if(cols_count <= 0)
+        {
+          std::cerr << "Base_DB_Table_Data::refresh_related_fields(): The result had 0 columns" << std::endl;
+        }
+
+        for(guint uiCol = 0; uiCol < cols_count; uiCol++)
+        {
+          const Gnome::Gda::Value value = result->get_value_at(uiCol, 0 /* row */);
+          sharedptr<LayoutItem_Field> layout_item = *iterFields;
+          if(!layout_item)
+            std::cerr << "Base_DB_Table_Data::refresh_related_fields(): The layout_item was null." << std::endl;
+          else
+          {
+            //std::cout << "DEBUG: Box_Data_List::refresh_related_fields(): field_name=" << layout_item->get_name() << std::endl;
+            //std::cout << "  DEBUG: Box_Data_List::refresh_related_fields(): value_as_string=" << value.to_string()  << std::endl;
+
+            //m_AddDel.set_value(row, layout_item, value);
+            set_entered_field_data(row, layout_item, value);
+            //g_warning("addedel size=%d", m_AddDel.get_count());
+          }
+
+          ++iterFields;
+        }
+      }
+      else
+        std::cerr << "Base_DB_Table_Data::refresh_related_fields(): no records found." << std::endl;
+    }
+  }
+}
+
+/** Get the shown fields that are in related tables, via a relationship using @a field_name changes.
+ */
+Base_DB_Table_Data::type_vecLayoutFields Base_DB_Table_Data::get_related_fields(const sharedptr<const LayoutItem_Field>& field) const
+{
+  type_vecLayoutFields result;
+
+  const Document_Glom* document = dynamic_cast<const Document_Glom*>(get_document());
+  if(document)
+  {
+    const Glib::ustring field_name = field->get_name(); //At the moment, relationships can not be based on related fields on the from side.
+    for(type_vecLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end();  ++iter)
+    {
+      sharedptr<LayoutItem_Field> layout_field = *iter;
+      //Examine each field that looks up its data from a relationship:
+      if(layout_field->get_has_relationship_name())
+      {
+        //Get the relationship information:
+        sharedptr<const Relationship> relationship = document->get_relationship(m_table_name, layout_field->get_relationship_name());
+        if(relationship)
+        {
+          //If the relationship uses the specified field:
+          if(relationship->get_from_field() == field_name)
+          {
+            //Add it:
+            result.push_back(layout_field);
+          }
+        }
+      }
+    }
+  }
+
+  return result;
+}
+
 } //namespace Glom
 
 
