@@ -26,7 +26,7 @@
 #include <gtkmm/entry.h>
 #include <gtkmm/label.h>
 #include "base_db.h"
-#include <glom/libglom/connectionpool.h>
+#include <libglom/connectionpool.h>
 
 namespace Glom
 {
@@ -39,7 +39,18 @@ public:
   Dialog_Connection(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
   virtual ~Dialog_Connection();
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   sharedptr<SharedConnection> connect_to_server_with_connection_settings() const;
+#else
+  sharedptr<SharedConnection> connect_to_server_with_connection_settings(std::auto_ptr<ExceptionConnection>& error) const;
+#endif
+
+  ///Disable irrelevant fields:
+  void set_connect_to_browsed();
+
+  void set_username(const Glib::ustring& username);
+  void set_password(const Glib::ustring& password);
+  void get_username_and_password(Glib::ustring& user, Glib::ustring& password) const;
 
   virtual void load_from_document(); //override
   
@@ -50,7 +61,7 @@ public:
    */
   void set_database_name(const Glib::ustring& name);
 
-protected:
+private:
   Gtk::Entry* m_entry_host;
   Gtk::Entry* m_entry_user;
   Gtk::Entry* m_entry_password;
