@@ -19,9 +19,12 @@
  */
 
 #include "dialog_field_summary.h"
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 Dialog_FieldSummary::Dialog_FieldSummary(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Gtk::Dialog(cobject),
   m_label_field(0),
@@ -62,10 +65,12 @@ sharedptr<LayoutItem_FieldSummary> Dialog_FieldSummary::get_item() const
 
 void Dialog_FieldSummary::on_button_field()
 {
-  sharedptr<LayoutItem_Field> field = offer_field_list(field, m_table_name, this);
+  sharedptr<LayoutItem_Field> field = offer_field_list(m_layout_item, m_table_name, this);
   if(field)
   {
     m_layout_item->set_field(field);
     set_item(m_layout_item, m_table_name); //Update the UI.
   }
 }
+
+} //namespace Glom
