@@ -90,7 +90,7 @@ Dialog_Layout_Calendar_Related::~Dialog_Layout_Calendar_Related()
 }
 
 
-void Dialog_Layout_Calendar_Related::set_document(const Glib::ustring& layout, Document_Glom* document, const sharedptr<const LayoutItem_CalendarPortal>& portal)
+void Dialog_Layout_Calendar_Related::set_document(const Glib::ustring& layout, const Glib::ustring& layout_platform, Document_Glom* document, const sharedptr<const LayoutItem_CalendarPortal>& portal)
 {
   m_portal = glom_sharedptr_clone(portal);
   
@@ -98,10 +98,10 @@ void Dialog_Layout_Calendar_Related::set_document(const Glib::ustring& layout, D
   if(portal)
     from_table = portal->get_from_table();
 
-  set_document(layout, document, from_table);
+  set_document(layout, layout_platform, document, from_table);
 }
 
-void Dialog_Layout_Calendar_Related::set_document(const Glib::ustring& layout, Document_Glom* document, const Glib::ustring& from_table)
+void Dialog_Layout_Calendar_Related::set_document(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document_Glom* document, const Glib::ustring& from_table)
 {
   if(!m_portal)
   {
@@ -111,7 +111,7 @@ void Dialog_Layout_Calendar_Related::set_document(const Glib::ustring& layout, D
   type_vecLayoutFields empty_fields; //Just to satisfy the base class.
 
   
-  Dialog_Layout::set_document(layout, document, from_table, empty_fields);
+  Dialog_Layout::set_document(layout_name, layout_platform, document, from_table, empty_fields);
   //m_table_name is now actually the parent_table_name.
 
   update_ui();
@@ -372,7 +372,7 @@ void Dialog_Layout_Calendar_Related::on_combo_date_field_changed()
 }
 
 //Overridden so we can show related fields instead of fields from the parent table:
-void Dialog_Layout_Calendar_Related::on_button_field_add()
+void Dialog_Layout_Calendar_Related::on_button_add_field()
 {
   //Get the chosen field:
   //std::cout << "debug: related relationship=" << glom_get_sharedptr_name(m_portal->get_related_relationship()) << std::endl;
