@@ -19,13 +19,13 @@
  */
 
 #include "report_builder.h"
-#include <glom/libglom/utils.h>
-#include <glom/libglom/data_structure/glomconversions.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_summary.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_verticalgroup.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_header.h>
-#include <glom/libglom/data_structure/layout/report_parts/layoutitem_footer.h>
+#include <libglom/utils.h>
+#include <libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_summary.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_verticalgroup.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_header.h>
+#include <libglom/data_structure/layout/report_parts/layoutitem_footer.h>
 #include <glom/xsl_utils.h>
 
 namespace Glom
@@ -47,9 +47,9 @@ void ReportBuilder::report_build_headerfooter(const FoundSet& found_set, xmlpp::
 
   //Add child parts:
   type_vecLayoutItems itemsToGet;
-  for(LayoutGroup::type_map_items::iterator iterChildren = group->m_map_items.begin(); iterChildren != group->m_map_items.end(); ++iterChildren)
+  for(LayoutGroup::type_list_items::iterator iterChildren = group->m_list_items.begin(); iterChildren != group->m_list_items.end(); ++iterChildren)
   {
-    sharedptr<LayoutItem> item = iterChildren->second;
+    sharedptr<LayoutItem> item = *iterChildren;
 
     sharedptr<LayoutItem_Text> item_text = sharedptr<LayoutItem_Text>::cast_dynamic(item);
     if(item_text)
@@ -94,9 +94,9 @@ void ReportBuilder::report_build_summary(const FoundSet& found_set, xmlpp::Eleme
 
   //Get fields
   type_vecLayoutItems itemsToGet;
-  for(LayoutGroup::type_map_items::iterator iterChildren = summary->m_map_items.begin(); iterChildren != summary->m_map_items.end(); ++iterChildren)
+  for(LayoutGroup::type_list_items::iterator iterChildren = summary->m_list_items.begin(); iterChildren != summary->m_list_items.end(); ++iterChildren)
   {
-    sharedptr<LayoutItem> item = iterChildren->second;
+    sharedptr<LayoutItem> item = *iterChildren;
 
     sharedptr<LayoutItem_GroupBy> pGroupBy = sharedptr<LayoutItem_GroupBy>::cast_dynamic(item);
     if(pGroupBy)
@@ -132,9 +132,9 @@ void ReportBuilder::report_build_groupby_children(const FoundSet& found_set, xml
 {
   //Get data and add child rows:
   type_vecLayoutItems itemsToGet;
-  for(LayoutGroup::type_map_items::iterator iterChildren = group_by->m_map_items.begin(); iterChildren != group_by->m_map_items.end(); ++iterChildren)
+  for(LayoutGroup::type_list_items::iterator iterChildren = group_by->m_list_items.begin(); iterChildren != group_by->m_list_items.end(); ++iterChildren)
   {
-    sharedptr<LayoutItem> item = iterChildren->second;
+    sharedptr<LayoutItem> item = *iterChildren;
 
     sharedptr<LayoutItem_GroupBy> pGroupBy = sharedptr<LayoutItem_GroupBy>::cast_dynamic(item);
     if(pGroupBy)
@@ -184,7 +184,7 @@ void ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
 
     sql_query += " GROUP BY " + field_group_by->get_name(); //rTODO: And restrict to the current found set.
 
-    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute(sql_query);
+    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query);
     if(datamodel)
     {
       guint rows_count = datamodel->get_n_rows();
@@ -200,6 +200,7 @@ void ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
         nodeGroupBy->set_attribute("group_value",
           Conversions::get_text_for_gda_value(field_group_by->get_glom_type(), group_value, field_group_by->get_formatting_used().m_numeric_format) );
 
+        //TODO: Use a SQL parameter instead of using sql().
         Glib::ustring where_clause = "(\"" + group_field_table_name + "\".\"" + field_group_by->get_name() + "\" = " + field_group_by->get_full_field_details()->sql(group_value) + ")";
         if(!found_set_parent.m_where_clause.empty())
           where_clause += " AND (" + found_set_parent.m_where_clause + ")";
@@ -208,14 +209,14 @@ void ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
         found_set_records.m_where_clause = where_clause;
 
         //Secondary fields. For instance, the Contact Name, in addition to the Contact ID that we group by.
-        if(!(group_by->m_group_secondary_fields->m_map_items.empty()))
+        if(!(group_by->m_group_secondary_fields->m_list_items.empty()))
         {
           xmlpp::Element* nodeSecondaryFields = nodeGroupBy->add_child("secondary_fields");
 
           type_vecLayoutItems itemsToGet;
-          for(LayoutGroup::type_map_items::iterator iterChildren = group_by->m_group_secondary_fields->m_map_items.begin(); iterChildren != group_by->m_group_secondary_fields->m_map_items.end(); ++iterChildren)
+          for(LayoutGroup::type_list_items::iterator iterChildren = group_by->m_group_secondary_fields->m_list_items.begin(); iterChildren != group_by->m_group_secondary_fields->m_list_items.end(); ++iterChildren)
           {
-            sharedptr<LayoutItem> item = iterChildren->second;
+            sharedptr<LayoutItem> item = *iterChildren;
             itemsToGet.push_back( glom_sharedptr_clone(item) );
           }
 
@@ -242,9 +243,9 @@ void ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
 
 void ReportBuilder::report_build_records_get_fields(const FoundSet& found_set, const sharedptr<LayoutGroup>& group, type_vecLayoutFields& items)
 {
-  for(LayoutGroup::type_map_items::iterator iterChildren = group->m_map_items.begin(); iterChildren != group->m_map_items.end(); ++iterChildren)
+  for(LayoutGroup::type_list_items::iterator iterChildren = group->m_list_items.begin(); iterChildren != group->m_list_items.end(); ++iterChildren)
   {
-    sharedptr<LayoutItem> item = iterChildren->second;
+    sharedptr<LayoutItem> item = *iterChildren;
 
     sharedptr<LayoutItem_VerticalGroup> pVerticalGroup = sharedptr<LayoutItem_VerticalGroup>::cast_dynamic(item);
     if(pVerticalGroup)
@@ -298,7 +299,7 @@ void ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
       }
     }
 
-    Glib::ustring sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
+   Glib::ustring sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
       fieldsToGet,
       found_set.m_where_clause, Glib::ustring() /* extra_join */, found_set.m_sort_clause);
 
@@ -307,10 +308,10 @@ void ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
       sql_query += " LIMIT 1";
 
     bool records_found = false;
-    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute(sql_query);
+    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query);
     if(datamodel)
     {
-      guint rows_count = datamodel->get_n_rows();
+      const guint rows_count = datamodel->get_n_rows();
       if(rows_count > 0)
         records_found = true;
 
@@ -379,7 +380,7 @@ void ReportBuilder::report_build_records_field(const FoundSet& found_set, xmlpp:
     //So let's get that data here:
     const Glib::ustring table_used = field->get_table_used(found_set.m_table_name);
     const Glib::ustring query = "SELECT \"" + table_used + "\".\"" + field->get_name() + "\" FROM \""+ table_used + "\" LIMIT 1";
-    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute(query);
+    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(query);
 
     if(!datamodel)
       return;
@@ -441,9 +442,9 @@ void ReportBuilder::report_build_records_vertical_group(const FoundSet& found_se
 {
   xmlpp::Element* nodeGroupVertical = parentNode.add_child(group->get_report_part_id());
 
-  for(LayoutGroup::type_map_items::iterator iterChildren = group->m_map_items.begin(); iterChildren != group->m_map_items.end(); ++iterChildren)
+  for(LayoutGroup::type_list_items::iterator iterChildren = group->m_list_items.begin(); iterChildren != group->m_list_items.end(); ++iterChildren)
   {
-    sharedptr<LayoutItem> item = iterChildren->second;
+    sharedptr<LayoutItem> item = *iterChildren;
 
     sharedptr<LayoutItem_VerticalGroup> pVerticalGroup = sharedptr<LayoutItem_VerticalGroup>::cast_dynamic(item);
     if(pVerticalGroup)
@@ -500,9 +501,9 @@ void ReportBuilder::report_build(const FoundSet& found_set, const sharedptr<cons
 
   type_vecLayoutItems itemsToGet_TopLevel;
 
-  for(LayoutGroup::type_map_items::const_iterator iter = report->m_layout_group->m_map_items.begin(); iter != report->m_layout_group->m_map_items.end(); ++iter)
+  for(LayoutGroup::type_list_items::const_iterator iter = report->m_layout_group->m_list_items.begin(); iter != report->m_layout_group->m_list_items.end(); ++iter)
   {
-    sharedptr<LayoutItem> pPart = iter->second;
+    sharedptr<LayoutItem> pPart = *iter;
 
     //The Group, and the details for each record in the group:
     sharedptr<LayoutItem_GroupBy> pGroupBy = sharedptr<LayoutItem_GroupBy>::cast_dynamic(pPart);
@@ -540,6 +541,11 @@ void ReportBuilder::report_build(const FoundSet& found_set, const sharedptr<cons
   {
     xmlpp::Element* nodeGroupBy = nodeParent->add_child("ungrouped_records");
 
+    // TODO: I am not sure where an exception could be thrown here. It seems
+    // not to be in glom, otherwise the code wouldn't compile with
+    // -fno-exceptions. If it's in a library, it does not seem to take an
+    // additional error paramater for that. armin.
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
       report_build_records(found_set, *nodeGroupBy, itemsToGet_TopLevel);
@@ -556,6 +562,9 @@ void ReportBuilder::report_build(const FoundSet& found_set, const sharedptr<cons
       handle_error(ex);
       return;
     }
+#else
+    report_build_records(found_set, *nodeGroupBy, itemsToGet_TopLevel);
+#endif
   }
 
   GlomXslUtils::transform_and_open(*pDocument, "print_report_to_html.xsl", parent_window);
