@@ -18,16 +18,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h" // For GLOM_ENABLE_MAEMO
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_MAEMO
 
 #include "adddel.h"
 #include <algorithm> //For std::find.
 #include <glibmm/i18n.h>
 #include "../cellrendererlist/cellrendererlist.h"
 #include "treeviewcolumn_glom.h"
-#include <glom/libglom/data_structure/glomconversions.h>
+#include <libglom/data_structure/glomconversions.h>
 #include "../../dialog_invalid_data.h"
-#include <glom/libglom/utils.h>
+#include <libglom/utils.h>
 #include "bakery/App/App_Gtk.h"
 #include <iostream> //For debug output.
 
